import kebabCase from 'lodash/fp/kebabCase';
import mapValues from 'lodash/fp/mapValues';
import curry from 'lodash/fp/curry';

var forkHandlers = function (handlers) {
  return function (e) {
    handlers.forEach(function (handler) {
      if (handler) handler(e);
    });
  };
};

function parseMetadata(metadata) {
  return metadata ? Object.keys(metadata).reduce(function (acc, key) {
    acc["data-" + kebabCase(key)] = metadata[key] || '';
    return acc;
  }, {}) : {};
}
/**
 * This function allows to generate a new object that
 * contains metadata with values suffixed with provided suffix
 *
 * @example
 *   ```ts
 *   suffixMetadata(metadata, 'inner')
 *   ```
 *
 * This function is curried:
 *
 * @example
 *   ```ts
 *   const { metadata } = props;
 *   const suffixedMeta = suffixMetadata(metadata);
 *   ...
 *   <div {...parseMetadata(suffixedMeta('innerPart1'))}>
 *     <div {...parseMetadata(suffixedMeta('innerPart2'))} />
 *   </div>
 *   ```
 *
 * @param {ComponentMetadata} metadata The original metadata object
 * @param {string} suffix A string to be added to the values of the original metadata object
 * @returns {ComponentMetadata} The metadata object with values containing suffixes
 */


var suffixMetadata = curry(function (metadata, suffix) {
  return mapValues(function (val) {
    return val + "-" + suffix;
  }, metadata);
});
export { forkHandlers, parseMetadata, suffixMetadata };
//# sourceMappingURL=index.js.map
